csep.core.catalogs.CSEPCatalog.get\_cumulative\_number\_of\_events
==================================================================

.. currentmodule:: csep.core.catalogs

.. automethod:: CSEPCatalog.get_cumulative_number_of_events